function rekon3DCal = axial_sensitivity_compensation(x,z,rekon3D,...
    tempRekon3D,threshold,dispPos)
% to compensate the sensitivity of the transducer array
% rekon3DCal = axial_sensitivity_compensation(x,z,rekon3D,...
% tempRekon3D,threshold,dispPos)
%   Input
%     x           : x coordinate of the 3D reconstruction
%     z           : z coordinate of the 3D reconstruction
%     rekon3D     : a 3D reconstruction (y,x,z)
%     tempRekon3D : a 4D matrix contains all 3D projections (N,y,x,z) with
%                   N is the the number of projections
%     threshold   : to threshold the 3D reconstruction
%     dispPos     : displacement positions
%
%   Output
%     rekon3DCal    : sensitivity compensated 3D reconstruction

fprintf('Sensitivity compensating....');
xStep = x(2)-x(1);
zStep = z(2)-z(1);
ySamples = size(rekon3D,1);
nOfDisp = length(dispPos);
dispPosRela = abs(dispPos-dispPos(1));
dispSamples = round((dispPosRela(end)-dispPosRela(1))/zStep);
mask3D = zeros(size(rekon3D));
mask3D(rekon3D>=threshold)=1;

rekon3DCal = rekon3D;
rekon3DCal(rekon3D<threshold) = 0;

% %% load the xz sensitivity map
% % and take only the positive x
% load('xzCalibration.mat')
% xCalIds = find(xCal>=0);
% xCal = xCal(xCalIds);
% xzCalibration = xzCalibration(:,xCalIds);
% 
% %% interpolate the sensitivity map
% % to match with the pixel size of the reconstructed image
% xCal = round(xCal/xStep)*xStep;
% zCal = round(zCal/zStep)*zStep;
% xIntpl = 0:xStep:xCal(end);
% zIntpl = zCal(1):zStep:zCal(end);
% sens2D = interp1(xCal,xzCalibration',xIntpl,'pchip');
% sens2D = interp1(zCal,sens2D',zIntpl,'pchip');
% sens2D = sens2D';
% sens2D = sens2D/max(sens2D(:));
% sens3D = repmat(sens2D, [1 1 ySamples]);
% sens3D = permute(sens3D,[3 1 2]);
% 
% %% shift the sensitivity map as the displacement
% shiftedSensZLength = size(sens2D,2)-dispSamples; % length of the sensitivity
%                                                  % map in z direction
% shiftedSens3D = zeros(nOfDisp, ySamples, size(sens2D,1), shiftedSensZLength);
% zIntpl(end-dispSamples+1:end) = [];
% for iDisp=1:nOfDisp
%     zShiftStart = round((dispPosRela(iDisp)-dispPosRela(1))/zStep);
%     zShiftEnd = zShiftStart+shiftedSensZLength;
%     shiftedSens3D(iDisp,:,:,:) = sens3D(:,:,zShiftStart+1:zShiftEnd);
% end
% 
% %% match the dimensions of the sensitivity map and the reconstructed image
% [~,zRekonStart] = min(abs(z-zIntpl(1)));
% zRekonEnd = length(z);
% zCalEnd = length(zIntpl);
% if zIntpl(end)<z(end)
%     zRekonEnd = zRekonStart+length(zIntpl)-1;
% else
%     zCalEnd = zRekonEnd-zRekonStart+1;
% end
% if xCal(end)<x(end)
%     [~,xEnd] = min(abs(x-xCal(end)));
% else
%     [~,xEnd] = min(abs(z-zCal(end)));
% end
% shiftedSens3D = shiftedSens3D(:,:,1:xEnd,1:zCalEnd);
% tempRekon3D = tempRekon3D(:,:,1:xEnd,zRekonStart:zRekonEnd);
% mask3D = mask3D(:,1:xEnd,zRekonStart:zRekonEnd);
% 
% %% compensate each projection
% maskIds = find(mask3D>0);
% cpstedRekon3D = zeros(ySamples,xEnd,zCalEnd);
% for iFile = 1:nOfDisp-1
%     tempRekon1 = squeeze(tempRekon3D(iFile,:,:,:));
%     tempSens1 = squeeze(shiftedSens3D(iFile,:,:,:));
%     tempRekon1(maskIds) = tempRekon1(maskIds)./tempSens1(maskIds);
%     for jFile = iFile+1:nOfDisp
%         tempRekon2 = squeeze(tempRekon3D(jFile,:,:,:));
%         tempSens2 = squeeze(shiftedSens3D(jFile,:,:,:));
%         tempRekon2(maskIds) = tempRekon2(maskIds)./tempSens2(maskIds);
%         tempRekon = tempRekon1.*abs(tempRekon2);
%         tempRekon = sign(tempRekon).*sqrt(abs(tempRekon));
%         cpstedRekon3D = cpstedRekon3D + tempRekon;
%     end
% end
% 
% %% hilbert transform
% for iX=1:xEnd
%     tempRekon = squeeze(cpstedRekon3D(:,iX,:))';
%     tempRekon = abs(hilbert(tempRekon));
%     cpstedRekon3D(:,iX,:) = tempRekon';
% end
% % threshold
% cpstedRekon3D = cpstedRekon3D.*mask3D;
% 
% % put the compensated rekon back into its real dimensions
% rekon3DCal(:,1:xEnd,zRekonStart:zRekonEnd) = cpstedRekon3D;
% fprintf('done!\n');