% function rf_data = IQ2RF(iq_data, iq_fs, f0, upsampleFact)
%
% converts IQ data (downmixed, downsampled analytic signal) to RF data (real signal).
%
% INPUT:
% iq_data: n-d array with IQ data set with time axis in first dimension
% iq_fs: sample frequency of IQ data in Hz
% f0: upmix frequency in Hz (frequency with which IQ signal was downmixed)
% upsampleFactor: integer factor with which the signal is upsampled
%
% author: Marvin Heller and Hans-Martin Schwab (marvin.heller-l87@rub.de)


function rf_data = convert_IQ_2_RF(iq_data, samplingFreq, centerFreq, upsampleFact)

% precomputation:
[Nt, ~, ~] = size(iq_data);
Nt_int = Nt * upsampleFact;

% upsampling:
rf_data = interpft(iq_data, Nt_int, 1);

% upmixing:
rf_fs = samplingFreq*upsampleFact;
t = (0:Nt_int-1)'/rf_fs;
rf_data = rf_data.*exp(1j*2*pi*centerFreq*t);
% rf_data = bsxfun(@times, rf_data, exp(1j*2*pi*f0*t));

% real signal:
rf_data = real(rf_data);


end