function data3D = create_3D_data(Settings,data2D,xShift)
% to create 3D projections
% data3D = create_3D_data(Settings,data2D,xShift)
% Input:
%   Settings = data acquisition settings of the transducer array
%   data2D: reconstructed pressure distribution(before Hilbert transform)
%   xShift: in case the projection needs some correction
% Output:
%   data3D: 3D projection
fprintf('Creating 3D projection......');
delay = Settings.delay*Settings.c;
delaySamples = round(delay/Settings.sampleDepth);
xNoSmpls = Settings.PA.frameLength+delaySamples;
xNoSmpls = ceil(sqrt(xNoSmpls^2-delaySamples^2));
yNoSmpls = size(data2D,1);
% profile on
%% prepare an empty 3D projection
nPoints = Settings.PA.frameLength*xNoSmpls;
data3D = zeros(yNoSmpls, nPoints);
% profile on
%% back projection
% prepare an xz grid
xCordinate = (0:xNoSmpls-1)*Settings.sampleDepth;
switch nargin
    case 3
        xCordinate = xCordinate - xShift*Settings.sampleDepth;
end
zCordinate = (0:Settings.PA.frameLength-1)*Settings.sampleDepth;
maxDist = (Settings.PA.frameLength+1)*Settings.sampleDepth;
if delay >= 0
    zCordinate = zCordinate + delay;
    maxDist = maxDist + delay;
else
    tempdata2D = zeros(size(data2D));
    tempdata2D(:, 1:end+delaySamples) = data2D(:, 1-delaySamples:end);
    data2D = tempdata2D;
end
[z,x] = meshgrid(zCordinate, xCordinate);
% calculate the distance between every grid to the origin [0,0]
distance = sqrt(x.^2 + z.^2);
% round the distance to match with the pixel size
distance = round(distance/Settings.sampleDepth)*Settings.sampleDepth;
% sort the distances to optimize the projection
distanceReshaped = reshape(distance, [],1);
tempIdx = find(distanceReshaped<maxDist);
tempDist = distanceReshaped(tempIdx);
[tempDist, sortedIds] = sort(tempDist);
tempIdx = tempIdx(sortedIds);
[~,ids] = unique(tempDist);
% project back the signal based on the distance
for idx=1:Settings.PA.frameLength
    % signals are back projected here
    data3D(:,tempIdx(ids(idx):ids(idx+1)-1)) = data3D(:,...
        tempIdx(ids(idx):ids(idx+1)-1)) + data2D(:,idx);
end
% profile viewer
data3D = reshape(data3D, yNoSmpls, xNoSmpls, Settings.PA.frameLength);
fprintf('done!\n');