function create_multi_3D_data(fp,fn,system,dispDir,displacement,saveData,newFn)
% to create 3D projections
% create_multi_3D_data(fp,fn,system,dispDir)
% Input:
%   fp = file path
%   fn: file names, data-acquired files
%   system: the PAI system
%      1: MyLabOne with a no-laser probe
%      2: MyLabOne with a laser-integrated probe
%      3: Eagle
%   dispDir: displacement direction
%      1: axial (z) displacement
%      2: elevation (x) displacement
%   saveData: save data or not
%      1: yes
%      else: no
%   newFn: 3D projections will be saved under these new file names
%   displacement: displacement distance. Only needed for x displacement

nFiles = length(fn);
%% read data
for iFile = 1:nFiles
    fprintf(['-------file number: ' num2str(iFile) ' -------\n']);
    if system==1 % myLabOne with a no-laser probe
        [signal,Settings] = read_process_noLaser([fp fn{iFile}],0,0);
    elseif system==2 % MyLabOne
        [Settings,Data] = read_data_myLabOne([fp fn{iFile}],0,0);
        [signal,Settings] = preprocess_data_PA_myLabOne(Settings,Data);
    elseif system==3 % Eagle
        [Settings,Data] = read_raw_data_eagle([fp fn{iFile}],0,0);
        [signal,Settings] = preprocess_data_PA_Eagle(Settings,Data);
    end
    if(ndims(signal)==3) % more than one laser trigger event such as in the
                         % case of a multi-wavelength probe
        if(iFile==1)
            % get the event giving strongest signal
            maxSignal = max(signal,[],[2 3]);
            [~,clearestImgIdx] = max(maxSignal);
        end
        signal = squeeze(signal(clearestImgIdx,:,:));
    end
    [~,data2D] = rekon_OA_freqdom(signal,Settings);
    if(dispDir==1) % z displacement
        curData3D = create_3D_data(Settings, data2D);
    elseif(dispDir==2) % x displacement
        xShift = round(displacement(iFile)/Settings.sampleDepth);
% % the beamforming requires very precise back projecting, this switch end
% % is to manually correct the errors introduced during the experiments,
% % e.g. error from the translation stage. Check in note.txt for this
% % statement
%         switch iFile
%             case 1
% 
%             case 2
%                 xShift = xShift + 4;
%             case 3
% 
%             case 4
%                 xShift = xShift + 3;
%             case 5
%                 xShift = xShift - 1;
%             case 6
%                 xShift = xShift + 2;
%         end
        curData3D = create_3D_data(Settings, data2D, xShift);
    end
    if(saveData==1)
        save([fp newFn{iFile}] , 'curData3D');
    end
end
