% function [rekon3D, rekon3DCal] = noLaser_DMAS_3D_axial_displacement(fp, newFn, Settings)
% 3D delay multiply and sum (DMAS) reconstruction with array axial
% displacement

%% select files
% dataPath = readDataPath;
dataPath = 'P:\TNW\BMPI\Users\Ho Nhu Y Nguyen\Published papers\3D view of out-of-plane artifacts\data';
[newFn, fp] = uigetfile('*.mat','Select 3D PA data sets','MultiSelect','on', dataPath);
if ~iscell(newFn) || length(newFn) < 3
    warning('not enough files, at least 3 files');
    return
end
newFn = newFn';
nFiles = length(newFn);
probeXs = zeros(nFiles, 1);
for iFile = 1:nFiles
    fileNameInfo = strsplit(newFn{iFile}, '_');
    probeXs(iFile) = str2double(fileNameInfo{5});
end
zFileIds = probeXs==mode(probeXs);
newFn = newFn(zFileIds);
Settings.pitch = 0.245; % transducer element Settings.pitch [mm]
Settings.c = 1.5; % speed of sound mm/us
Settings.acq.fs = 50e6; % sampling rate
Settings.sampleDepth = Settings.c*1e6/Settings.acq.fs; % depth of each sample

%% sort files
nFiles = length(newFn);
probeZs = zeros(nFiles, 1);
for iFile = 1:nFiles
    fileNameInfo = strsplit(newFn{iFile}, '_');
    probeZs(iFile) = str2double(fileNameInfo{3});
end
[probeZs, sortOrd] = sort(probeZs, 'descend');
newFn = newFn(sortOrd);
load([fp newFn{end}]);
zMaxSamples = size(curData3D,3);
xMaxSamples = size(curData3D,2);
load([fp newFn{1}]);
zMinSamples = size(curData3D,3);
xMinSamples = size(curData3D,2);
if zMinSamples>zMaxSamples
    [probeZs, sortOrd] = sort(probeZs);
    newFn = newFn(sortOrd);
    zMinSamples = zMaxSamples;
    xMinSamples = xMaxSamples;
    warning('initially sorted in a wrong order!');
end
xSamples = xMinSamples;
zSamples = zMinSamples;

%% DMAS
rekon3D = zeros(64, xSamples, zSamples);
tempRekon3D = zeros(nFiles, 64, xSamples, zSamples);
for iFile=1:nFiles
    load([fp newFn{iFile}]);
    curData3D = curData3D(:,1:xSamples,end-zSamples+1:end);
    tempCurData = zeros(size(curData3D));
    zShift = 0;
    tempCurData(:,:,zShift+1:end) = curData3D(:,:,1:end-zShift);
    tempRekon3D(iFile,:,:,:) = tempCurData;
end

% for iFile = 1:nFiles-1
%     temp1 = squeeze(tempRekon3D(iFile,:,:,:));
%     for jFile = iFile+1:nFiles
%         temp2 = squeeze(tempRekon3D(jFile,:,:,:));
%         tempRekon = temp1.*abs(temp2);
%         tempRekon = sign(tempRekon).*sqrt(abs(tempRekon));
%         rekon3D = rekon3D + tempRekon;
%     end
for iFile = 1:nFiles
    tempRekon = squeeze(tempRekon3D(iFile,:,:,:));
    rekon3D = rekon3D + tempRekon;
end

%% hilbert transform
% [b,a] = butter(5,[2e6 14e6]/(Settings.acq.fs/2), 'bandpass');
for iX=1:xSamples
    tempRekon = squeeze(rekon3D(:,iX,:))';    
    tempRekon = padarray(tempRekon, 64, 0, 'both'); % add some padding
%     tempRekon = filter(b, a, tempRekon);
    tempRekon = abs(hilbert(tempRekon));
    tempRekon = tempRekon(65:end-64,:);
    rekon3D(:,iX,:) = tempRekon';
end