function [signal,Settings,Data] = preprocess_data_PA_Eagle(Settings,Data)

fprintf('Preprocessing RF Data.......');
offSetIdx = 9; % offset of acquiring data. It starts acquiring offSetIdx
               % pixels before the laser triggered
cutOffIdx1 = round(80*Settings.acq.fs/32.5e6); % to remove trigger noise
               % the number of pixels depends on the sampling frequency. It
               % is ~ 40 pixels at 32.5 MHz
cutOffHalfIdx = 5; % some strange distortion might happen within last 5 pixels
Settings.PA.acqDepth = [1 Settings.PA.frameLength]*Settings.sampleDepth;

% remove DC and trigger noise
Data.PA.dataRF(1:offSetIdx,:,:) = []; % remove offset
Settings.PA.frameLength = Settings.PA.frameLength - offSetIdx;
Data.PA.dataRF(1:cutOffIdx1,:,:) = 0; % remove trigger noise
Data.PA.dataRF(end-cutOffHalfIdx:end,:,:) = 0; % remove strange distortion
Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:) = Data.PA.dataRF(...
    cutOffIdx1+1:end-cutOffHalfIdx-1,:,:)-mean(Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:));

% reorder read data
Data.PA.dataRF = permute(Data.PA.dataRF, [3,1,2]);

% separate laser trigger events
nEvents = length(Settings.PA.events);
signal = zeros(nEvents, Settings.PA.frameLength, Settings.finfo.nrl);
for iEvent = 1:nEvents
    indices = Settings.PA.lm(4,:) == Settings.PA.events(iEvent);
    frames = Data.PA.dataRF(indices,:,:);
    tempFrame = squeeze(mean(frames));
    tempFrame(cutOffIdx1+1:end-cutOffHalfIdx-1, :) = detrend(tempFrame(cutOffIdx1+1:end-cutOffHalfIdx-1, :), 'constant');
    signal(iEvent,:,:) = tempFrame;
end
fprintf('done!\n');
