function [signal,Settings,Data] = preprocess_data_PA_myLabOne(Settings,Data)

fprintf('Preprocessing RF Data.......');

cutOffIdx1 = round(80*Settings.acq.fs/(200e6/7)); % to remove trigger noise
               % the number of pixels depends on the sampling frequency. It
               % is ~ 80 pixels at 200/7 MHz
cutOffHalfIdx = 5; % some strange distortion might happen within last 5 pixels
Settings.PA.cutOffIdx1 = cutOffIdx1;
Settings.PA.cutOffHalfIdx = cutOffHalfIdx;
Settings.PA.acqDepth = [1 Settings.PA.frameLength]*Settings.sampleDepth;

% remove DC and trigger noise
Data.PA.dataRF(1:cutOffIdx1,:,:) = 0; % remove trigger noise
Data.PA.dataRF(end-cutOffHalfIdx:end,:,:) = 0; % remove strange distortion
Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:) = Data.PA.dataRF(...
    cutOffIdx1+1:end-cutOffHalfIdx-1,:,:)-mean(Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:));
[b,a] = butter(5, 0.5e6/(Settings.acq.fs/2), 'high');
Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:) = filter(b,a,...
    Data.PA.dataRF(cutOffIdx1+1:end-cutOffHalfIdx-1,:,:));

% reorder read data
Data.PA.dataRF = permute(Data.PA.dataRF, [3,1,2]);

% separate laser trigger events
Settings.PA.events = unique(Settings.PA.lm(4,:));
if Settings.PA.events(1) == 0
    Settings.PA.events(1) = [];
end
nEvents = length(Settings.PA.events);
signal = zeros(nEvents, Settings.PA.frameLength, Settings.finfo.nrl);
for iEvent = 1:nEvents
    indices = Settings.PA.lm(4,:)==Settings.PA.events(iEvent);
    frames = Data.PA.dataRF(indices,:,:);
    tempFrame = squeeze(mean(frames));
    tempFrame(cutOffIdx1+1:end-cutOffHalfIdx-1,:) = detrend(tempFrame(cutOffIdx1+1:end-cutOffHalfIdx-1,:),'constant');
    signal(iEvent,:,:) = tempFrame;
end
fprintf('done!\n');