function [Settings,Data] = read_data_myLabOne(filePath,beginFrame,nOfFrame)
% to read a data file in filePath of a MyLabOne
% [Settings,Data] = read_data_myLabOne(filePath,beginFrame,nOfFrame)
%   Input
%     filePath    : path to data files
%     beginFrame  : first frame being read, 0 for reading the very first
%                   frame
%     nr_frames   : Number of frames to read, 0 for reading all frames,
%                   negative for reading Settings only%
%   Output
%     Settings    : a structure containing all settings
%     Data        : a structure containing raw data

%% read data
[Settings,Data] = Read_RFe_V2c(filePath,beginFrame,nOfFrame);
Settings.pitch = 0.245; % transducer element Settings.pitch [mm]
Settings.c = 1.5; % speed of sound mm/us
Settings.delay = -1.05; % time delay from laser irradiation to signal acquisition start
Settings.sampleDepth = Settings.c*1e6/Settings.acq.fs; % depth of each sample
Settings.acqY = [1, Settings.finfo.nrl]*Settings.pitch; % acquired Y length

if(nOfFrame<0)
    signal = 0;
    return
end

% get PA data
idcPA = Settings.lm(12,:)==0;
Settings.PA.lm = Settings.lm(:,idcPA);
Settings.PA.frameLength = Settings.PA.lm(11,1);
Data.PA.dataRF = Data.dataRF(1:Settings.PA.frameLength,:,idcPA);
Settings.PA.nr_frames = size(Data.PA.dataRF,3);


% get US data:
idcUS = Settings.lm(12,:)==1;
Data.US.dataRF = Data.dataRF(:,:,idcUS);
Data.US.dataRF = permute(Data.US.dataRF,[3 1 2]);
Settings.US.lm = Settings.lm(:,idcUS);
Settings.US.nr_frames = size(Data.US.dataRF,3);
Settings.US.frameLength = Settings.US.lm(11,1);