function [signal, Settings, Data] = read_process_noLaser(filePath, beginFrame, nOfFrame)
% to read a data file in filePath and then preprocess data of a MyLabOne
% using a no-laser probe
% [signal, Settings, Data]= read_process_noLaser(filePath, beginFrame,
% noOfFrame)
%   Input
%     filePath    : path to data files
%     beginFrame  : first frame being read, 0 for reading the very first
%                   frame
%     nr_frames   : Number of frames to read, 0 for reading all frames,
%                   negative for reading Settings only%
%   Output
%     signal      : preprocessed RF data
%     Settings    : a structure containing all settings
%     Data        : a structure containing raw data

%% read data
[Settings,Data] = Read_RFe_V2c(filePath, beginFrame, nOfFrame);
Settings.pitch = 0.245; % transducer element Settings.pitch [mm]
Settings.c = 1.5; % speed of sound mm/us
Settings.delay = 1.41; % time delay from laser irradiation to signal acquisition start
Settings.sampleDepth = Settings.c*1e6/Settings.acq.fs; % depth of each sample
Settings.PA.frameLength = Settings.finfo.nrs;
Settings.PA.halfFrameLength = round(Settings.lm(5,1)/2);
Settings.acqDepth = [1, Settings.PA.halfFrameLength]*Settings.sampleDepth;
Settings.acqY = [1, Settings.finfo.nrl]*Settings.pitch; % acquired Y length
if(nOfFrame<0)
    signal = 0;
    return
end
Data.PA.dataRF = Data.dataRF(1:Settings.PA.frameLength,:,:);

%% process data
cutOffEnd = 5; % some strange distortion might happen within last 5 pixels
Settings.PA.acqDepth = [1 Settings.PA.frameLength]*Settings.sampleDepth;

% remove DC and trigger noise
Data.PA.dataRF(end-cutOffEnd:end,:,:) = 0; % remove strange distortion
Data.PA.dataRF(1:end-cutOffEnd-1,:,:) = Data.PA.dataRF(...
    1:end-cutOffEnd-1,:,:)-mean(Data.PA.dataRF(1:end-cutOffEnd-1,:,:));

% reorder read data
Data.PA.dataRF = permute(Data.PA.dataRF, [3,1,2]);

signal = squeeze(mean(Data.PA.dataRF));
signal(1:end-cutOffEnd-1,:) = detrend(signal(1:end-cutOffEnd-1,:),'constant');