function [Settings, Data] = read_raw_data_eagle(filePath, beginFrame, nOfFrame)
% to read raw data acquired with an Eagle
% [Settings, Data] = read_raw_data_eagle(filePath, beginFrame, nOfFrame)
%   Input
%     filePath    : path to data files
%     beginFrame  : first frame being read, 0 for reading the very first
%                   frame
%     nr_frames   : Number of frames to read, 0 for reading all frames,
%                   negative for reading Settings only%
%   Output
%     Settings    : a structure containing all settings
%     Data        : a structure containing raw data

[Settings,Data] = read_rfe_eagle(filePath,beginFrame,nOfFrame);
Settings.centerFreq = 7.5e6;
Settings.pitch = 0.245; % transducer element Settings.pitch [mm]
Settings.c = 1.5; % speed of sound mm/us
Settings.delay =  0; % [us]
Settings.sampleDepth = Settings.c*1e6/Settings.acq.fs;
Settings.acqY = [1 Settings.finfo.nrl]*Settings.pitch; % acquired Y length

if(nOfFrame<0)
    return
end

% get PA data
idcPA = Settings.lm(12,:)==0;
Settings.PA.lm = Settings.lm(:,idcPA);
Settings.PA.frameLength = Settings.PA.lm(11,1);
Data.PA.dataIQ = Data.dataIQ(1:Settings.PA.frameLength,:,idcPA);
Settings.PA.nr_frames = size(Data.PA.dataIQ,3);


% get US data:
idcUS = Settings.lm(12,:)==1;
Data.US.dataIQ = Data.dataIQ(:,:,idcUS);
Settings.US.lm = Settings.lm(:,idcUS);
Settings.US.nr_frames = size(Data.US.dataIQ,3);
Settings.US.frameLength = Settings.US.lm(11,1);

Data.PA.dataRF  = convert_IQ_2_RF(Data.PA.dataIQ, Settings.acq.fs, Settings.centerFreq, 1);

Settings.PA.events = unique(Settings.PA.lm(4,:));
if Settings.PA.events(1) == 0
    Settings.PA.events(1) = [];
end
