function [rekon3D,rekon3DCal] = recon_3D(fp,newFn,Settings,dispDir,probePos)
% to reconstruct 3D images
% [rekon3D,rekon3DCal] = recon_3D(fp,newFn,Settings,dispDir,probeXs)
% Input:
%   fp = file path
%   newFn: 3D projection files
%   Settings: structure contains necessary information
%   dispDir: displacement direction
%      1: axial (z) displacement
%      2: elevation (x) displacement
%   dispStep: displacement step size. Only needed when system = 2 or 3
% Output:
%   rekon3D: reconstructed 3D image
%   rekon3DCal: sensitivity-compensated reconstructed 3D image

fprintf('Reconstructing 3D...........');
%% load 3D projections
nFiles = length(newFn);
load([fp newFn{1}]);
[ySamples,xSamples,zSamples] = size(curData3D);
rekon3D = zeros(ySamples, xSamples, zSamples);
tempRekon3D = zeros(nFiles, ySamples, xSamples, zSamples);
for iFile=1:nFiles
    load([fp newFn{iFile}]);
    if(dispDir==1) % z displacement
        if(iFile>1 && size(curData3D,3)>zSamples)
            % in case of myLabOne with a no-laser probe. In axial
            % displacement, imaging depth increased corresponding to the
            % displacement -> crop out the redundant image depth
            tempRekon3D(iFile,:,:,:) = curData3D(:,1:xSamples,end-zSamples+1:end);
        else
            zShift = round(probePos(iFile)/Settings.sampleDepth);
            tempRekon3D(iFile,:,:,1:end-zShift) = curData3D(:,:,zShift+1:end);
        end
    elseif(dispDir==2) % x displacement
        tempRekon3D(iFile,:,:,:) = curData3D;
    end    
end

%% Back-projection and multiplication
for iFile = 1:nFiles-1
    temp1 = squeeze(tempRekon3D(iFile,:,:,:));
    for jFile = iFile+1:nFiles
        temp2 = squeeze(tempRekon3D(jFile,:,:,:));
        tempRekon = temp1.*abs(temp2);
        tempRekon = sign(tempRekon).*sqrt(abs(tempRekon));
        rekon3D = rekon3D + tempRekon;
    end
% %% Direct back-projection
% for iFile = 1:nFiles
%     tempRekon = squeeze(tempRekon3D(iFile,:,:,:));
%     rekon3D = rekon3D + tempRekon;
end

%% Zero padding and Hilbert transform
[b,a] = butter(5,[2e6 14e6]/(Settings.acq.fs/2), 'bandpass');
for iX=1:xSamples
    tempRekon = squeeze(rekon3D(:,iX,:))';    
    tempRekon = padarray(tempRekon, 64, 0, 'both'); % add some padding
    tempRekon = filter(b,a,tempRekon);
    tempRekon = abs(hilbert(tempRekon));
    tempRekon = tempRekon(65:end-64,:);
    rekon3D(:,iX,:) = tempRekon';
end
fprintf('done!\n');

%% Compensate sensitivity
x = (0:zSamples-1)*Settings.sampleDepth;
z = (0:zSamples-1)*Settings.sampleDepth;
threshold = max(rekon3D(:))/6;
if(dispDir==1) % z displacement
    rekon3DCal = axial_sensitivity_compensation(x,z,rekon3D,...
        tempRekon3D,threshold,probePos);
elseif(dispDir==2) % x displacement
    rekon3DCal = elevation_sensitivity_compensation(x,z,rekon3D,...
        tempRekon3D,threshold,probePos);
end