close all

%% read data
displacementStep = 0.525;
dataPath = 'P:\TNW\BMPI\Users\Ho Nhu Y Nguyen\Published papers\3D view of out-of-plane artifacts\data';
[fn, fp] = uigetfile('*.rfe','Select the INPUT DATA FILE(s)','MultiSelect','on', dataPath);
nFiles = length(fn);
if nFiles < 2
    warning('not enough files, at least 2 files');
    return
end
fn = fn';
fileStamp = zeros(nFiles, 1);
for iFile = 1:nFiles
    fileNameInfo = strsplit(fn{iFile}, {'_','.rfe'});
    fileStamp(iFile) = str2double(fileNameInfo{3});
end
[fileStamp, sortedIds] = sort(fileStamp);
fn = fn(sortedIds);
nFiles = ceil(nFiles/2);
fn = fn([1,nFiles+1:end]);
displacement = (0:nFiles-1)*displacementStep;

for iFile = 1:nFiles
    [Settings,Data] = read_data_myLabOne([fp fn{iFile}],0,0);
    [tempSignal,Settings,Data] = preprocess_data_PA_myLabOne(Settings,Data);
    if iFile == 1
        nEvents = length(Settings.PA.events);
        signal = zeros(nFiles, nEvents, Settings.PA.frameLength, Settings.lm(6,1));
    end
    signal(iFile,:,:,:) = tempSignal;
end
Settings.nFiles = nFiles;

%% reconstruct images
fprintf('Reconstructing image...');
zSamples = size(signal, 3);
Settings.c = 1.5; % speed of sound mm/us
Settings.delay = -1.05; % time delay from laser irradiation to signal acquisition start
Settings.sampleDepth = Settings.c*1e6/Settings.acq.fs; % depth of each sample
Settings.acqDepth = (1:zSamples)*Settings.sampleDepth;
rekon = zeros(size(signal));


for iFile=1:nFiles
    for iEvent = 1:nEvents
        zShift = round(displacement(iFile)/Settings.sampleDepth);
        tempRekon = rekon_OA_freqdom(squeeze(signal(iFile, iEvent,:,:)), Settings);
        rekon(iFile, iEvent, 1:end-zShift, :) = tempRekon(zShift+1:end, :);
    end
end
fprintf('done!\n');
rekon4 = squeeze(rekon(:,4,:,:)); % select wavelength #4

%% compute binary masks
rekonBW = zeros(size(rekon4));
segRekon = zeros(size(rekon4));
for iFile = 1:nFiles
    tempRekon = squeeze(rekon4(iFile,:,:));
    tempRekonBW = zeros(size(tempRekon));
    Objects = segment_image(tempRekon, Settings);
    tempRekonBW(Objects.allObjPxls) = 1;
    rekonBW(iFile,:,:) = tempRekonBW;
    segRekon(iFile,Objects.allObjPxls) = tempRekon(Objects.allObjPxls);
end

%% correct frame by frame
segCorrectedRekon = segRekon;
for iFile=2:nFiles
    mask = squeeze(sum(rekonBW(1:iFile,:,:)))<iFile;
    tempFrame = squeeze(segCorrectedRekon(1,:,:));
    tempFrame(mask) = 0;
    segCorrectedRekon(iFile,:,:) = tempFrame;
end

%% de-segment the corrected image
correctedRekon = rekon4;
for iFile=1:nFiles
    tempMask = squeeze(segCorrectedRekon(iFile,:,:));
    tempRekon = squeeze(rekon4(1, :, :));
    tempCorrectedImg = deprocess_peaks_v2(tempMask, tempRekon);
    correctedRekon(iFile,:,:) = tempCorrectedImg;
end

%% show results
iFile = 1;
% figure
while iFile <= nFiles
    clf
    tempRekon = squeeze(rekon4(iFile,:,:));
    subplot(1,2,1)
    imagesc(Settings.acqY, Settings.acqDepth, (tempRekon));
    colormap(hot);
%     colormap(cmap);
    axis image
    ylabel('z [mm]');
    xlabel('y [mm]');
    title(['original ' num2str(max(tempRekon(:)))]);
%     colorbar

    tempRekonCorrected = squeeze(correctedRekon(iFile,:,:));
    subplot(1,2,2)
%     imagesc(Settings.acqY, (1:minSamples)*Settings.sampleDepth, (tempRekonCorrected));
    imagesc(Settings.acqY, Settings.acqDepth, tempRekonCorrected);
    colormap(hot);
%     colormap(cmap);
    axis image
    ylabel('z [mm]');
    xlabel('y [mm]');
    title('out-of-plane artifacts corrected');
    pause(0.3);

    iFile = iFile + 1;
end
